@@ -34,6 +34,13 @@ REGISTRY = {
             "url": "https://github.com/fatiando-data/british-columbia-lidar/releases/download/v1",
         },
     },
+    "bushveld-gravity.csv.xz": {
+        "v1": {
+            "hash": "md5:368284cc210c6bbe256e9e49e892f262",
+            "doi": "doi:10.5281/zenodo.6511942",
+            "url": "https://github.com/fatiando-data/bushveld-gravity/releases/download/v1",
+        },
+    },
     "caribbean-bathymetry.csv.xz": {
         "v1": {
             "hash": "md5:a7332aa6e69c77d49d7fb54b764caa82",
@@ -62,6 +69,20 @@ REGISTRY = {
             "url": "https://github.com/fatiando-data/earth-topography-10arcmin/releases/download/v1",
         },
     },
+    "osborne-magnetic.csv.xz": {
+        "v1": {
+            "hash": "md5:b26777bdde2f1ecb97dda655c8b1cf71",
+            "doi": "doi:10.5281/zenodo.5882209",
+            "url": "https://github.com/fatiando-data/osborne-magnetic/releases/download/v1",
+        },
+    },
+    "sierra-negra-topography.csv.xz": {
+        "v1": {
+            "hash": "md5:9f6f64d47d26773e37b154cf964724e3",
+            "doi": "doi:10.5281/zenodo.6139057",
+            "url": "https://github.com/fatiando-data/sierra-negra-topography/releases/download/v1",
+        },
+    },
     "southern-africa-gravity.csv.xz": {
         "v1": {
             "hash": "md5:1dee324a14e647855366d6eb01a1ef35",
@@ -69,6 +90,13 @@ REGISTRY = {
             "url": "https://github.com/fatiando-data/southern-africa-gravity/releases/download/v1",
         },
     },
+    "southern-africa-topography.nc": {
+        "v1": {
+            "hash": "md5:609d14fe4e551c5dcf320cdceedd30e8",
+            "doi": "doi:10.5281/zenodo.6481379",
+            "url": "https://github.com/fatiando-data/southern-africa-topography/releases/download/v1",
+        },
+    },
 }
 
 
@@ -272,7 +300,7 @@ def fetch_britain_magnetic(version):
 
 def fetch_british_columbia_lidar(version):
     """
-    Lidar point cloud data of the Trail Islands in BC, Canada
+    Topography (lidar point cloud) data of the Trail Islands in BC, Canada
 
     This is a lidar point cloud (ground reflections only) sliced to the small
     `Trail Islands <https://apps.gov.bc.ca/pub/bcgnws/names/21973.html>`__
@@ -316,6 +344,53 @@ def fetch_british_columbia_lidar(version):
     return Path(_repository(fname, version).fetch(fname))
 
 
+def fetch_bushveld_gravity(version):
+    """
+    Gravity ground-based data over the Bushveld Complex, Southern Africa
+
+    This dataset contains ground gravity observations over the area that
+    comprises the Bushveld Igenous Complex in Southern Africa, including
+    preprocessed gravity fields such as the **gravity disturbance** and the
+    **bouguer gravity disturbance** (topography-free gravity disturbance). In
+    addition, the dataset contains the heights of the observation points
+    referenced on the WGS84 reference ellipsoid and over the mean sea-level
+    (what can be considered to be the geoid). This dataset was built upon
+    a portion of the Southern Africa gravity compilation available through
+    `NOAA NCEI <https://www.ngdc.noaa.gov/mgg/gravity/>`__.
+
+    **Format:** CSV with xz (lzma) compression.
+
+    **Load with:** :func:`pandas.read_csv`
+
+    **Original source:** `NOAA NCEI <https://www.ngdc.noaa.gov/mgg/gravity/>`__
+    (gravity) and `ETOPO1 <https://doi.org/10.7289/V5C8276M>`__ (topography)
+
+    **Original license:** `public domain
+    <https://ngdc.noaa.gov/ngdcinfo/privacy.html>`__ (gravity) and `public
+    domain <https://ngdc.noaa.gov/mgg/global/dem_faq.html#sec-2.4>`__
+    (topography)
+
+    **Versions:**
+
+    * `1
+      <https://github.com/fatiando-data/bushveld-gravity/releases/tag/v1>`_
+      (doi:`10.5281/zenodo.6511942 <https://doi.org/10.5281/zenodo.6511942>`__)
+
+    Parameters
+    ----------
+    version : int
+        The data version to fetch. See the available versions above.
+
+    Returns
+    -------
+    fname : :class:`pathlib.Path`
+        Path to the downloaded file on disk.
+    """
+    _check_versions(version, allowed={1}, name="Bushveld gravity data")
+    fname = "bushveld-gravity.csv.xz"
+    return Path(_repository(fname, version).fetch(fname))
+
+
 def fetch_caribbean_bathymetry(version):
     """
     Single-beam bathymetry of the Caribbean
@@ -501,6 +576,99 @@ def fetch_earth_topography(version):
     return Path(_repository(fname, version).fetch(fname))
 
 
+def fetch_osborne_magnetic(version):
+    """
+    Magnetic airborne survey of the Osborne Mine and surroundings, Australia
+
+    This is a section of a survey acquired in 1990 by the Queensland
+    Government, Australia. The line data have approximately 80 m terrain
+    clearance and 200 m line spacing. Total field anomalies are in nT. The
+    flight height was calculated by summing the terrain clearance to
+    interpolated values of SRTM (referenced to sea level). The section contains
+    the total field magnetic anomalies associated with the Osborne Mine,
+    Lightning Creek sill complex, and the Brumby prospect.
+
+    There are ~990,000 measurements in total with 5 columns available: flight
+    line number, longitude, latitude (geodetic), height (orthometric), and the
+    total field magnetic anomaly.
+
+    **Format:** CSV with xz (lzma) compression.
+
+    **Load with:** :func:`pandas.read_csv`
+
+    **Original source:** `Geophysical Acquisition & Processing Section 2019.
+    MIM Data from Mt Isa Inlier, QLD (P1029), magnetic line data, AWAGS
+    levelled. Geoscience Australia, Canberra
+    <http://pid.geoscience.gov.au/dataset/ga/142419>`__
+
+    **Original license:** CC-BY
+
+    **Versions:**
+
+    * `1
+      <https://github.com/fatiando-data/osborne-magnetic/releases/tag/v1>`_
+      (doi:`10.5281/zenodo.5882209 <https://doi.org/10.5281/zenodo.5882209>`__)
+
+    Parameters
+    ----------
+    version : int
+        The data version to fetch. See the available versions above.
+
+    Returns
+    -------
+    fname : :class:`pathlib.Path`
+        Path to the downloaded file on disk.
+
+    """
+    _check_versions(version, allowed={1}, name="Osborne mine magnetic")
+    fname = "osborne-magnetic.csv.xz"
+    return Path(_repository(fname, version).fetch(fname))
+
+
+def fetch_sierra_negra_topography(version):
+    """
+    Topography of the 2018 lava flows of the Sierra Negra volcano, Ecuador
+
+    This is a structure-from-motion point cloud of the 2018 lava flows of the
+    Sierra Negra volcano, located on the Galápagos islands, Ecuador. The survey
+    is of a small region on the flank of the volcano. The horizontal datum is
+    WGS84 but the vertical datum for "elevation" is unspecified.
+
+    There are ~1,700,000 measurements in total with 3 columns available:
+    longitude, latitude (geodetic), elevation.
+
+    **Format:** CSV with xz (lzma) compression.
+
+    **Load with:** :func:`pandas.read_csv`
+
+    **Original source:** `Carr, B. (2020). Sierra Negra Volcano (TIR Flight 3):
+    Galápagos, Ecuador, October 22 2018. Distributed by OpenTopography.
+    <https://doi.org/10.5069/G957196P>`__
+
+    **Original license:** CC-BY
+
+    **Versions:**
+
+    * `1
+      <https://github.com/fatiando-data/sierra-negra-topography/releases/tag/v1>`_
+      (doi:`10.5281/zenodo.6139057 <https://doi.org/10.5281/zenodo.6139057>`__)
+
+    Parameters
+    ----------
+    version : int
+        The data version to fetch. See the available versions above.
+
+    Returns
+    -------
+    fname : :class:`pathlib.Path`
+        Path to the downloaded file on disk.
+
+    """
+    _check_versions(version, allowed={1}, name="Sierra Negra volcano topography")
+    fname = "sierra-negra-topography.csv.xz"
+    return Path(_repository(fname, version).fetch(fname))
+
+
 def fetch_southern_africa_gravity(version):
     """
     Gravity ground-based surveys of Southern Africa
@@ -544,3 +712,42 @@ def fetch_southern_africa_gravity(version):
     _check_versions(version, allowed={1}, name="Southern Africa gravity")
     fname = "southern-africa-gravity.csv.xz"
     return Path(_repository(fname, version).fetch(fname))
+
+
+def fetch_southern_africa_topography(version):
+    """
+    Topography and bathymetry data for Southern Africa
+
+    This is a topography and bathymetry grid with a resolution of 1 arc-minute
+    over Southern Africa. The grid was generated by cropping the ETOPO1 global
+    topography grid. The heights are referenced to the mean sea level.
+
+    **Format:** netCDF4 with zlib compression
+
+    **Load with:** :func:`xarray.load_dataarray` (requires the `netcdf4
+    <https://github.com/Unidata/netcdf4-python>`__ library)
+
+    **Original source:** `ETOPO1 <https://doi.org/10.7289/V5C8276M>`__
+
+    **Original license:** Public domain
+
+    **Versions:**
+
+    * `1
+      <https://github.com/fatiando-data/southern-africa-topography/releases/tag/v1>`_
+      (doi:`10.5281/zenodo.6481379 <https://doi.org/10.5281/zenodo.6481379>`__)
+
+    Parameters
+    ----------
+    version : int
+        The data version to fetch. See the available versions above.
+
+    Returns
+    -------
+    fname : :class:`pathlib.Path`
+        Path to the downloaded file on disk.
+
+    """
+    _check_versions(version, allowed={1}, name="Southern Africa topography")
+    fname = "southern-africa-topography.nc"
+    return Path(_repository(fname, version).fetch(fname))
